Struct rusty_lr_core::InvalidTerminalError

source ·
pub struct InvalidTerminalError<Term> {
    pub term: Term,
    pub expected: Vec<Term>,
}
Error type for feed(), when invalid terminal is feeded

Fields

term: Term

invalid terminal feeded

expected: Vec<Term>

expected terminals

Implementations

source

impl<Term> InvalidTerminalError<Term>

source

pub fn backtrace<NonTerm>( parser: &impl GetParser<Term, NonTerm>, context: &impl GetContext<Term, NonTerm>, ) -> Vec<BTreeSet<ShiftedRuleRef>>
where NonTerm: PartialEq,

Generate backtrace information. This trace back on the state stack, and fetch the ruleset of each state. Each ruleset in the returned Vec contains every rule that the state was trying to parse, that is, only the rules with shifted > 0. 0’th index is the latest, that is, the last element of Vec will hold the initial state’s ruleset.

source

pub fn message(&self) -> String
where Term: Display,

Generate brief error message.

source

pub fn long_message<NonTerm>( &self, parser: &impl GetParser<Term, NonTerm>, context: &impl GetContext<Term, NonTerm>, ) -> String
where Term: Display + Hash + Eq, NonTerm: Display + PartialEq,

Generate long, detailed error message.