Struct rusty_lr_core::InvalidTerminalError
source · pub struct InvalidTerminalError<Term> {
pub term: Term,
pub expected: Vec<Term>,
}Expand description
Error type for feed(), when invalid terminal is feeded
Fields
term: Terminvalid terminal feeded
expected: Vec<Term>expected terminals
Implementations
sourceimpl<Term> InvalidTerminalError<Term>
impl<Term> InvalidTerminalError<Term>
sourcepub fn backtrace<NonTerm>(
parser: &impl GetParser<Term, NonTerm>,
context: &impl GetContext<Term, NonTerm>,
) -> Vec<BTreeSet<ShiftedRuleRef>>where
NonTerm: PartialEq,
pub fn backtrace<NonTerm>(
parser: &impl GetParser<Term, NonTerm>,
context: &impl GetContext<Term, NonTerm>,
) -> Vec<BTreeSet<ShiftedRuleRef>>where
NonTerm: PartialEq,
Generate backtrace information.
This trace back on the state stack, and fetch the ruleset of each state.
Each ruleset in the returned Vec contains every rule that the state was trying to parse, that is, only the rules with shifted > 0.
0’th index is the latest, that is, the last element of Vec will hold the initial state’s ruleset.
sourcepub fn long_message<NonTerm>(
&self,
parser: &impl GetParser<Term, NonTerm>,
context: &impl GetContext<Term, NonTerm>,
) -> String
pub fn long_message<NonTerm>( &self, parser: &impl GetParser<Term, NonTerm>, context: &impl GetContext<Term, NonTerm>, ) -> String
Generate long, detailed error message.